pub struct Session { /* private fields */ }Implementations
Sourceimpl Session
impl Session
Sourcepub fn new(
server_url: &str,
server_port: &str,
api_key: &str,
) -> Result<Self, SVMClientError>
pub fn new( server_url: &str, server_port: &str, api_key: &str, ) -> Result<Self, SVMClientError>
Creates a new session with the given server and RPC configuration.
Sourcepub fn existing(
server_url: &str,
server_port: &str,
api_key: &str,
session_id: &str,
) -> Result<Self, SVMClientError>
pub fn existing( server_url: &str, server_port: &str, api_key: &str, session_id: &str, ) -> Result<Self, SVMClientError>
Creates an existing session by restoring it from a session ID.
Sourcepub async fn start(
&mut self,
genesis_accounts: HashMap<Pubkey, Account>,
) -> Result<Uuid, SVMClientError>
pub async fn start( &mut self, genesis_accounts: HashMap<Pubkey, Account>, ) -> Result<Uuid, SVMClientError>
Starts a new session by sending a request with the provided genesis accounts.
Sourcepub async fn send_transaction(
&self,
tx: Transaction,
) -> Result<u8, SVMClientError>
pub async fn send_transaction( &self, tx: Transaction, ) -> Result<u8, SVMClientError>
Sends a transaction within the active session.
Sourcepub async fn end(&self, proof_type: ProofType) -> Result<(), SVMClientError>
pub async fn end(&self, proof_type: ProofType) -> Result<(), SVMClientError>
Ends the active session and kicks off the proving process.
Sourcepub async fn poll_status(&self) -> Result<PollSessionResponse, SVMClientError>
pub async fn poll_status(&self) -> Result<PollSessionResponse, SVMClientError>
Polls the session status from the server.